import os
import copy
import json
import requests

default_url = os.getenv('URL', 'https://nvision.nipa.cloud/api/v1/')
default_headers = {
    'Content-Type': 'application/json; charset=utf-8',
}


def scrub_dict(d):
    new_dict = {}
    for k, v in d.items():
        if isinstance(v, dict):
            v = scrub_dict(v)
        if v not in (u'', None, {}):
            new_dict[k] = v
    return new_dict


class API(object):
    def __init__(self, api_key, service_name):
        self.service_name = service_name
        self.endpoint = default_url + service_name
        self.headers = copy.copy(default_headers)
        self.headers['Authorization'] = 'ApiKey {}'.format(api_key)

    def predict(self,
                image,
                confidence_threshold=0.1,
                output_cropped_image=False,
                output_visualized_image=False):
        """
        docstring: Make a RESTful request for model inference
            :param image: base64 encoded string
            :param confidence_threshold: float
                - value options: [0,1]
                - default: 0.1
            :param output_cropped_image: Boolean
                - value options: True or False,
                - default: False
            :param output_visualized_image: Boolean
                - value options: True or False,
                - default: False
        """

        data = {
            "raw_data": image,
            "configurations": [{
                "parameter": "ConfidenceThreshold",
                "value": str(confidence_threshold)
            }, {
                "parameter": "OutputCroppedImage",
                "value": str(output_cropped_image).lower()
            }, {
                "parameter": "OutputVisualizedImage",
                "value": str(output_visualized_image).lower()
            }]
        }

        response = requests.post(url=self.endpoint,
                                 headers=self.headers,
                                 data=json.dumps(data))

        return response


class ObjectDetection(API):
    def __init__(self, api_key):
        super().__init__(api_key, service_name='object-detection')


class FaceDetection:
    def __init__(self, api_key):
        super().__init__(api_key, service_name='face-detection')



import os
import json
import base64
from nvision import ObjectDetection

model = ObjectDetection(api_key=os.getenv('API_KEY'))

# base64 encoded string
with open(os.path.join('docs', 'street.jpg'), 'rb') as file:
    image = file.read()
    image = base64.b64encode(image).decode('utf-8')

# Make a RESTful call to the Nvision API
response = model.predict(image)

print(response)
print(json.dumps(response.json(), indent=4, sort_keys=True))



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="nvision",
    version="1.4.0",
    author="Nipa Cloud Platform",
    author_email="devr@nipa.cloud",
    description="Nipa Cloud Platform: Nvision Python SDK",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/nipa-cloud/nvision-python",
    packages=['nvision'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: Apache Software License",
        "Intended Audience :: Developers",
    ],
    keywords=[
        'Machine Learning',
        'Deep Learning',
        'Computer Vision',
        'Nipa Cloud Service'
    ],
    python_requires=">=3.5",
    install_requires=["requests>=2.22.0",
                      "numpy>=1.18.1",
                      "bleach>=2.1.0"])
